@@ -5,7 +5,7 @@ from django.core.validators import validate_email
 from floraconcierge.apiauth.models import User
 from floraconcierge.errors import ResultDefaultError
 from floraconcierge.shortcuts import get_apiclient
-from floraconcierge.shortcuts.users import login, get_logged_user
+from floraconcierge.shortcuts.users import login, get_logged_user, social_login
 
 
 class FloraConciergeBackend(ModelBackend):
@@ -33,3 +33,11 @@ class FloraConciergeBackend(ModelBackend):
                 return User.from_api_user(user)
         except ResultDefaultError:
             return None
+
+
+class FloraConciergeOauthBackend(FloraConciergeBackend):
+    def authenticate(self, flora_token=None, **kwargs):
+        try:
+            return User.from_api_user(social_login(flora_token))
+        except ResultDefaultError, e:
+            raise ValidationError(e.message)
